# Edit Site

Namespace: `core/edit-site`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/edit-site/src/store/selectors.js) -->

### getCanUserCreateMedia

Returns whether the current user can create media or not.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Whether the current user can create media or not.

### getCurrentTemplateNavigationPanelSubMenu

> **Deprecated**

### getCurrentTemplateTemplateParts

Returns the template parts and their blocks for the current edited template.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: Template parts and their blocks in an array.

### getEditedPostContext

> **Deprecated**

Returns the edited post's context object.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Page.

### getEditedPostId

Returns the ID of the currently edited template or template part.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Post ID.

### getEditedPostType

Returns the current edited post type (wp_template or wp_template_part).

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?TemplateType`: Template type.

### getEditorMode

Returns the current editing mode.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Editing mode.

### getHomeTemplateId

> **Deprecated**

### getNavigationPanelActiveMenu

> **Deprecated**

### getPage

> **Deprecated**

Returns the current page object.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Page.

### getReusableBlocks

Returns any available Reusable blocks.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: The available reusable blocks.

### getSettings

Returns the site editor settings.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Settings.

### hasPageContentFocus

> **Deprecated**

Whether or not the editor allows only page content to be edited.

_Returns_

-   `boolean`: Whether or not focus is on editing page content.

### isFeatureActive

> **Deprecated**

Returns whether the given feature is enabled or not.

_Parameters_

-   _state_ `Object`: Global application state.
-   _featureName_ `string`: Feature slug.

_Returns_

-   `boolean`: Is active.

### isInserterOpened

> **Deprecated**

Returns true if the inserter is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the inserter is opened.

### isListViewOpened

Returns true if the list view is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the list view is opened.

### isNavigationOpened

> **Deprecated**

### isPage

Whether or not the editor has a page loaded into it.

_Related_

-   setPage

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether or not the editor has a page loaded into it.

### isSaveViewOpened

Returns the current opened/closed state of the save panel.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if the save panel should be open; false if closed.

<!-- END TOKEN(Autogenerated selectors|../../../packages/edit-site/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/edit-site/src/store/actions.js) -->

### addTemplate

> **Deprecated**

Action that adds a new template and sets it as the current template.

_Parameters_

-   _template_ `Object`: The template.

_Returns_

-   `Object`: Action object used to set the current template.

### closeGeneralSidebar

Action that closes the sidebar.

### openGeneralSidebar

Action that opens an editor sidebar.

_Parameters_

-   _name_ `?string`: Sidebar name to be opened.

### openNavigationPanelToMenu

> **Deprecated**

Opens the navigation panel and sets its active menu at the same time.

### removeTemplate

Action that removes a template.

_Parameters_

-   _template_ `Object`: The template object.

### revertTemplate

Reverts a template to its original theme-provided file.

_Parameters_

-   _template_ `Object`: The template to revert.
-   _options_ `[Object]`:
-   _options.allowUndo_ `[boolean]`: Whether to allow the user to undo reverting the template. Default true.

### setEditedEntity

Action that sets an edited entity.

_Parameters_

-   _postType_ `string`: The entity's post type.
-   _postId_ `string`: The entity's ID.
-   _context_ `Object`: The entity's context.

_Returns_

-   `Object`: Action object.

### setEditedPostContext

Set's the current block editor context.

_Parameters_

-   _context_ `Object`: The context object.

_Returns_

-   `Object`: Action object.

### setHasPageContentFocus

Sets whether or not the editor allows only page content to be edited.

_Parameters_

-   _hasPageContentFocus_ `boolean`: True to allow only page content to be edited, false to allow template to be edited.

### setHomeTemplateId

> **Deprecated**

### setIsInserterOpened

> **Deprecated**

Returns an action object used to open/close the inserter.

_Parameters_

-   _value_ `boolean|Object`: Whether the inserter should be opened (true) or closed (false).

### setIsListViewOpened

> **Deprecated**

Returns an action object used to open/close the list view.

_Parameters_

-   _isOpen_ `boolean`: A boolean representing whether the list view should be opened or closed.

### setIsNavigationPanelOpened

> **Deprecated**

Sets whether the navigation panel should be open.

### setIsSaveViewOpened

Sets whether the save view panel should be open.

_Parameters_

-   _isOpen_ `boolean`: If true, opens the save view. If false, closes it. It does not toggle the state, but sets it directly.

### setNavigationMenu

Action that sets a navigation menu.

_Parameters_

-   _navigationMenuId_ `string`: The Navigation Menu Post ID.

_Returns_

-   `Object`: Action object.

### setNavigationPanelActiveMenu

> **Deprecated**

Action that sets the active navigation panel menu.

_Returns_

-   `Object`: Action object.

### setPage

> **Deprecated**

Resolves the template for a page and displays both. If no path is given, attempts to use the postId to generate a path like `?p=${ postId }`.

_Returns_

-   `Object`: Action object.

### setTemplate

Action that sets a template, optionally fetching it from REST API.

_Returns_

-   `Object`: Action object.

### setTemplatePart

Action that sets a template part.

_Parameters_

-   _templatePartId_ `string`: The template part ID.

_Returns_

-   `Object`: Action object.

### switchEditorMode

> **Deprecated**

Triggers an action used to switch editor mode.

_Parameters_

-   _mode_ `string`: The editor mode.

### toggleDistractionFree

> **Deprecated**

Action that toggles Distraction free mode. Distraction free mode expects there are no sidebars, as due to the z-index values set, you can't close sidebars.

### toggleFeature

Dispatches an action that toggles a feature flag.

_Parameters_

-   _featureName_ `string`: Feature name.

### updateSettings

Returns an action object used to update the settings.

_Parameters_

-   _settings_ `Object`: New settings.

_Returns_

-   `Object`: Action object.

<!-- END TOKEN(Autogenerated actions|../../../packages/edit-site/src/store/actions.js) -->
